/*  -- translated by f2c (version 20160102).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* ----------------------------------------------------------------------- */
/*     CONTACT POINTS */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int umscnt_0_(int n__, real *xcnt, real *ycnt, real *rot)
{
    static real rotz, xcntz, ycntz;

    switch(n__) {
	case 1: goto L_umqcnt;
	}

    xcntz = *xcnt;
    ycntz = *ycnt;
    rotz = *rot;
    return 0;
/* ----------------------------------------------------------------------- */

L_umqcnt:
    *xcnt = xcntz;
    *ycnt = ycntz;
    *rot = rotz;
    return 0;
} /* umscnt_ */

/* Subroutine */ int umscnt_(real *xcnt, real *ycnt, real *rot)
{
    return umscnt_0_(0, xcnt, ycnt, rot);
    }

/* Subroutine */ int umqcnt_(real *xcnt, real *ycnt, real *rot)
{
    return umscnt_0_(1, xcnt, ycnt, rot);
    }

